Type: Package
Package: gt
Title: Easily Create Presentation-Ready Display Tables
Version: 0.11.1
Authors@R: c(
    person("Richard", "Iannone", , "rich@posit.co", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0003-3925-190X")),
    person("Joe", "Cheng", , "joe@posit.co", role = "aut"),
    person("Barret", "Schloerke", , "barret@posit.co", role = "aut",
           comment = c(ORCID = "0000-0001-9986-114X")),
    person("Ellis", "Hughes", , "ellis.h.hughes@gsk.com", role = "aut",
           comment = c(ORCID = "0000-0003-0637-4436")),
    person("Alexandra", "Lauer", , "alexandralauer1@gmail.com", role = "aut",
           comment = c(ORCID = "0000-0002-4191-6301")),
    person("JooYoung", "Seo", , "jseo1005@illinois.edu", role = "aut",
           comment = c(ORCID = "0000-0002-4064-6012")),
    person("Ken", "Brevoort", , "ken@brevoort.com", role = "aut",
           comment = c(ORCID = "0000-0002-4001-8358")),
    person("Olivier", "Roy", role = "aut"),
    person("Posit Software, PBC", role = c("cph", "fnd"))
  )
Description: Build display tables from tabular data with an easy-to-use
    set of functions. With its progressive approach, we can construct
    display tables with a cohesive set of table parts. Table values can be
    formatted using any of the included formatting functions. Footnotes
    and cell styles can be precisely added through a location targeting
    system. The way in which 'gt' handles things for you means that you
    don't often have to worry about the fine details.
License: MIT + file LICENSE
URL: https://gt.rstudio.com, https://github.com/rstudio/gt
BugReports: https://github.com/rstudio/gt/issues
Depends: R (>= 3.6.0)
Imports: base64enc (>= 0.1-3), bigD (>= 0.2), bitops (>= 1.0-7), cli
        (>= 3.6.3), commonmark (>= 1.9.1), dplyr (>= 1.1.4), fs (>=
        1.6.4), glue (>= 1.8.0), htmltools (>= 0.5.8.1), htmlwidgets
        (>= 1.6.4), magrittr (>= 2.0.3), markdown (>= 1.13), reactable
        (>= 0.4.4), rlang (>= 1.1.4), sass (>= 0.4.9), scales (>=
        1.3.0), tidyselect (>= 1.2.1), vctrs, xml2 (>= 1.3.6)
Suggests: digest (>= 0.6.31), fontawesome (>= 0.5.2), ggplot2, grid,
        gtable, knitr, lubridate, magick, paletteer, RColorBrewer,
        rmarkdown (>= 2.20), rsvg, rvest, shiny (>= 1.9.1), testthat
        (>= 3.1.9), tidyr, withr
Config/Needs/coverage: officer
Config/Needs/website: quarto
ByteCompile: true
Config/testthat/edition: 3
Config/testthat/parallel: true
Encoding: UTF-8
LazyData: true
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.2
Author: Richard Iannone [aut, cre] (<https://orcid.org/0000-0003-3925-190X>),
  Joe Cheng [aut],
  Barret Schloerke [aut] (<https://orcid.org/0000-0001-9986-114X>),
  Ellis Hughes [aut] (<https://orcid.org/0000-0003-0637-4436>),
  Alexandra Lauer [aut] (<https://orcid.org/0000-0002-4191-6301>),
  JooYoung Seo [aut] (<https://orcid.org/0000-0002-4064-6012>),
  Ken Brevoort [aut] (<https://orcid.org/0000-0002-4001-8358>),
  Olivier Roy [aut],
  Posit Software, PBC [cph, fnd]
Maintainer: Richard Iannone <rich@posit.co>
Built: R 4.4.2; ; 2024-11-25 15:22:51 UTC; unix
