# Generated by roxygen2: do not edit by hand

S3method("$",gt_option)
S3method(add_text_style,character)
S3method(add_text_style,shiny.tag)
S3method(as.data.frame,gt_tbl)
S3method(as.tags,gt_tbl)
S3method(cell_style_to_html,cell_border)
S3method(cell_style_to_html,cell_fill)
S3method(cell_style_to_html,cell_text)
S3method(cell_style_to_html,default)
S3method(knitr::knit_print,gt_group)
S3method(knitr::knit_print,gt_tbl)
S3method(plot,gt_gtable)
S3method(plot,gt_tbl)
S3method(print,gt_group)
S3method(print,gt_tbl)
S3method(print,rtf_text)
S3method(resolve_location,cells_body)
S3method(resolve_location,cells_column_labels)
S3method(resolve_location,cells_column_spanners)
S3method(resolve_location,cells_row_groups)
S3method(resolve_location,cells_stub)
S3method(resolve_location,resolved)
S3method(set_footnote,cells_body)
S3method(set_footnote,cells_column_labels)
S3method(set_footnote,cells_column_spanners)
S3method(set_footnote,cells_footnotes)
S3method(set_footnote,cells_grand_summary)
S3method(set_footnote,cells_row_groups)
S3method(set_footnote,cells_source_notes)
S3method(set_footnote,cells_stub)
S3method(set_footnote,cells_stub_summary)
S3method(set_footnote,cells_stubhead)
S3method(set_footnote,cells_summary)
S3method(set_footnote,cells_title)
S3method(set_style,cells_body)
S3method(set_style,cells_column_labels)
S3method(set_style,cells_column_spanners)
S3method(set_style,cells_footnotes)
S3method(set_style,cells_grand_summary)
S3method(set_style,cells_row_groups)
S3method(set_style,cells_source_notes)
S3method(set_style,cells_stub)
S3method(set_style,cells_stub_grand_summary)
S3method(set_style,cells_stub_summary)
S3method(set_style,cells_stubhead)
S3method(set_style,cells_summary)
S3method(set_style,cells_title)
S3method(text_transform_at_location,cells_body)
S3method(text_transform_at_location,cells_column_labels)
S3method(text_transform_at_location,cells_column_spanners)
S3method(text_transform_at_location,cells_row_groups)
S3method(text_transform_at_location,cells_stub)
S3method(to_output_location,cells_body)
S3method(to_output_location,cells_stub)
S3method(to_output_location,default)
S3method(to_output_location,output_relative)
export("%>%")
export(adjust_luminance)
export(all_of)
export(any_of)
export(as_gtable)
export(as_latex)
export(as_raw_html)
export(as_rtf)
export(as_word)
export(cell_borders)
export(cell_fill)
export(cell_text)
export(cells_body)
export(cells_column_labels)
export(cells_column_spanners)
export(cells_footnotes)
export(cells_grand_summary)
export(cells_group)
export(cells_row_groups)
export(cells_source_notes)
export(cells_stub)
export(cells_stub_grand_summary)
export(cells_stub_summary)
export(cells_stubhead)
export(cells_summary)
export(cells_title)
export(cols_add)
export(cols_align)
export(cols_align_decimal)
export(cols_hide)
export(cols_label)
export(cols_label_with)
export(cols_merge)
export(cols_merge_n_pct)
export(cols_merge_range)
export(cols_merge_uncert)
export(cols_move)
export(cols_move_to_end)
export(cols_move_to_start)
export(cols_nanoplot)
export(cols_unhide)
export(cols_units)
export(cols_width)
export(contains)
export(css)
export(currency)
export(data_color)
export(default_fonts)
export(ends_with)
export(escape_latex)
export(everything)
export(extract_body)
export(extract_cells)
export(extract_summary)
export(fmt)
export(fmt_auto)
export(fmt_bins)
export(fmt_bytes)
export(fmt_chem)
export(fmt_country)
export(fmt_currency)
export(fmt_date)
export(fmt_datetime)
export(fmt_duration)
export(fmt_email)
export(fmt_engineering)
export(fmt_flag)
export(fmt_fraction)
export(fmt_icon)
export(fmt_image)
export(fmt_index)
export(fmt_integer)
export(fmt_markdown)
export(fmt_missing)
export(fmt_number)
export(fmt_partsper)
export(fmt_passthrough)
export(fmt_percent)
export(fmt_roman)
export(fmt_scientific)
export(fmt_spelled_num)
export(fmt_tf)
export(fmt_time)
export(fmt_units)
export(fmt_url)
export(from_column)
export(ggplot_image)
export(google_font)
export(grand_summary_rows)
export(grp_add)
export(grp_clone)
export(grp_options)
export(grp_pull)
export(grp_replace)
export(grp_rm)
export(gt)
export(gt_group)
export(gt_latex_dependencies)
export(gt_output)
export(gt_preview)
export(gt_split)
export(gtsave)
export(html)
export(info_currencies)
export(info_date_style)
export(info_flags)
export(info_google_fonts)
export(info_icons)
export(info_locales)
export(info_paletteer)
export(info_time_style)
export(info_unit_conversions)
export(local_image)
export(matches)
export(md)
export(nanoplot_options)
export(num_range)
export(one_of)
export(opt_align_table_header)
export(opt_all_caps)
export(opt_css)
export(opt_footnote_marks)
export(opt_footnote_spec)
export(opt_horizontal_padding)
export(opt_interactive)
export(opt_row_striping)
export(opt_stylize)
export(opt_table_font)
export(opt_table_lines)
export(opt_table_outline)
export(opt_vertical_padding)
export(pct)
export(px)
export(random_id)
export(render_gt)
export(rm_caption)
export(rm_footnotes)
export(rm_header)
export(rm_source_notes)
export(rm_spanners)
export(rm_stubhead)
export(row_group)
export(row_group_order)
export(rows_add)
export(starts_with)
export(stub)
export(sub_large_vals)
export(sub_missing)
export(sub_small_vals)
export(sub_values)
export(sub_zero)
export(summary_rows)
export(system_fonts)
export(tab_caption)
export(tab_footnote)
export(tab_header)
export(tab_info)
export(tab_options)
export(tab_row_group)
export(tab_source_note)
export(tab_spanner)
export(tab_spanner_delim)
export(tab_stub_indent)
export(tab_stubhead)
export(tab_style)
export(tab_style_body)
export(test_image)
export(text_case_match)
export(text_case_when)
export(text_replace)
export(text_transform)
export(unit_conversion)
export(vars)
export(vec_fmt_bytes)
export(vec_fmt_currency)
export(vec_fmt_date)
export(vec_fmt_datetime)
export(vec_fmt_duration)
export(vec_fmt_engineering)
export(vec_fmt_fraction)
export(vec_fmt_index)
export(vec_fmt_integer)
export(vec_fmt_markdown)
export(vec_fmt_number)
export(vec_fmt_partsper)
export(vec_fmt_percent)
export(vec_fmt_roman)
export(vec_fmt_scientific)
export(vec_fmt_spelled_num)
export(vec_fmt_time)
export(web_image)
export(where)
import(rlang)
importFrom(dplyr,vars)
importFrom(htmltools,as.tags)
importFrom(htmltools,css)
importFrom(magrittr,"%>%")
importFrom(tidyselect,all_of)
importFrom(tidyselect,any_of)
importFrom(tidyselect,contains)
importFrom(tidyselect,ends_with)
importFrom(tidyselect,everything)
importFrom(tidyselect,matches)
importFrom(tidyselect,num_range)
importFrom(tidyselect,one_of)
importFrom(tidyselect,starts_with)
importFrom(tidyselect,where)
importFrom(xml2,`xml_attr<-`)
importFrom(xml2,`xml_text<-`)
importFrom(xml2,as_xml_document)
importFrom(xml2,read_xml)
importFrom(xml2,xml_add_child)
importFrom(xml2,xml_add_sibling)
importFrom(xml2,xml_attr)
importFrom(xml2,xml_child)
importFrom(xml2,xml_children)
importFrom(xml2,xml_contents)
importFrom(xml2,xml_find_all)
importFrom(xml2,xml_find_first)
importFrom(xml2,xml_name)
importFrom(xml2,xml_ns)
importFrom(xml2,xml_remove)
importFrom(xml2,xml_text)
importFrom(xml2,xml_type)
