---
title: "html-02-morley"
output:
  - html_document
---

```{r setup, include=FALSE}
knitr::opts_chunk$set(echo = TRUE)
library(gt)
```

Create a display table based on `morley`.

```{r}
gt(morley) %>%
  fmt_number(
    columns = Speed,
    decimals = 0,
    sep_mark = ",") %>%
  cols_align(align = "left", columns = c(Run, Speed))
```
