---
title: "html-04-sleep"
output:
  - html_document
---

```{r setup, include=FALSE}
knitr::opts_chunk$set(echo = TRUE)
library(gt)
```

Create a display table based on `sleep`.

```{r}
gt(sleep) %>%
  fmt_scientific(columns = extra) %>%
  tab_footnote(
    footnote = "This is a footnote",
    locations = cells_body(columns = 1, rows = c(2, 3, 4))
  )
```
