# word ooxml can be generated from gt object

    Code
      as_word(gt_tbl, ...)
    Output
      [1] "<w:tbl xmlns:w=\"http://schemas.openxmlformats.org/wordprocessingml/2006/main\" xmlns:wp=\"http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing\" xmlns:r=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships\" xmlns:w14=\"http://schemas.microsoft.com/office/word/2010/wordml\"><w:tblPr><w:tblCellMar><w:top w:w=\"0\" w:type=\"dxa\"></w:top><w:bottom w:w=\"0\" w:type=\"dxa\"></w:bottom><w:start w:w=\"60\" w:type=\"dxa\"></w:start><w:end w:w=\"60\" w:type=\"dxa\"></w:end></w:tblCellMar><w:tblW w:type=\"auto\" w:w=\"0\"></w:tblW><w:tblLook w:firstRow=\"0\" w:lastRow=\"0\" w:firstColumn=\"0\" w:lastColumn=\"0\" w:noHBand=\"0\" w:noVBand=\"0\"></w:tblLook><w:jc w:val=\"center\"></w:jc></w:tblPr><w:tr><w:trPr><w:cantSplit></w:cantSplit><w:tblHeader></w:tblHeader></w:trPr><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">num</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">char</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"center\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">fctr</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">date</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">time</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">datetime</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">currency</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">row</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">group</w:t>\n  </w:r>\n</w:p></w:tc></w:tr><w:tr><w:trPr><w:cantSplit></w:cantSplit></w:trPr><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">0.1111</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">apricot</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"center\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">one</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">2015-01-15</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">13:35</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">2018-01-01 02:22</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">49.95</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">row_1</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">grp_a</w:t>\n  </w:r>\n</w:p></w:tc></w:tr></w:tbl>"

---

    Code
      as_word(gt_tbl, ...)
    Output
      [1] "<w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n    <w:pStyle w:val=\"caption\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"24\"/>\n    </w:rPr>\n    <w:t xml:space=\"preserve\">Table </w:t>\n  </w:r>\n  <w:r>\n    <w:fldChar w:fldCharType=\"begin\" w:dirty=\"true\"/>\n  </w:r>\n  <w:r>\n    <w:instrText xml:space=\"preserve\" w:dirty=\"true\"> SEQ Table \\* ARABIC </w:instrText>\n  </w:r>\n  <w:r>\n    <w:fldChar w:fldCharType=\"separate\" w:dirty=\"true\"/>\n  </w:r>\n  <w:r>\n    <w:rPr>\n      <w:noProof/>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"24\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">1</w:t>\n  </w:r>\n  <w:r>\n    <w:fldChar w:fldCharType=\"end\" w:dirty=\"true\"/>\n  </w:r>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"24\"/>\n    </w:rPr>\n    <w:t xml:space=\"preserve\">: </w:t>\n  </w:r>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"24\"/>\n      <w:color w:val=\"333333\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">TABLE TITLE</w:t>\n  </w:r>\n</w:p><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n    <w:pStyle w:val=\"caption\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n      <w:color w:val=\"333333\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">table subtitle</w:t>\n  </w:r>\n</w:p><w:tbl xmlns:w=\"http://schemas.openxmlformats.org/wordprocessingml/2006/main\" xmlns:wp=\"http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing\" xmlns:r=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships\" xmlns:w14=\"http://schemas.microsoft.com/office/word/2010/wordml\"><w:tblPr><w:tblCellMar><w:top w:w=\"0\" w:type=\"dxa\"></w:top><w:bottom w:w=\"0\" w:type=\"dxa\"></w:bottom><w:start w:w=\"60\" w:type=\"dxa\"></w:start><w:end w:w=\"60\" w:type=\"dxa\"></w:end></w:tblCellMar><w:tblW w:type=\"auto\" w:w=\"0\"></w:tblW><w:tblLook w:firstRow=\"0\" w:lastRow=\"0\" w:firstColumn=\"0\" w:lastColumn=\"0\" w:noHBand=\"0\" w:noVBand=\"0\"></w:tblLook><w:jc w:val=\"center\"></w:jc></w:tblPr><w:tr><w:trPr><w:cantSplit></w:cantSplit><w:tblHeader></w:tblHeader></w:trPr><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">num</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">char</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"center\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">fctr</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">date</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">time</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">datetime</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">currency</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">row</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">group</w:t>\n  </w:r>\n</w:p></w:tc></w:tr><w:tr><w:trPr><w:cantSplit></w:cantSplit></w:trPr><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">0.1111</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">apricot</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"center\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">one</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">2015-01-15</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">13:35</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">2018-01-01 02:22</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">49.95</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">row_1</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">grp_a</w:t>\n  </w:r>\n</w:p></w:tc></w:tr></w:tbl>"

---

    Code
      as_word(gt_tbl, ...)
    Output
      [1] "<w:tbl xmlns:w=\"http://schemas.openxmlformats.org/wordprocessingml/2006/main\" xmlns:wp=\"http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing\" xmlns:r=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships\" xmlns:w14=\"http://schemas.microsoft.com/office/word/2010/wordml\"><w:tblPr><w:tblCellMar><w:top w:w=\"0\" w:type=\"dxa\"></w:top><w:bottom w:w=\"0\" w:type=\"dxa\"></w:bottom><w:start w:w=\"60\" w:type=\"dxa\"></w:start><w:end w:w=\"60\" w:type=\"dxa\"></w:end></w:tblCellMar><w:tblW w:type=\"auto\" w:w=\"0\"></w:tblW><w:tblLook w:firstRow=\"0\" w:lastRow=\"0\" w:firstColumn=\"0\" w:lastColumn=\"0\" w:noHBand=\"0\" w:noVBand=\"0\"></w:tblLook><w:jc w:val=\"center\"></w:jc></w:tblPr><w:tr><w:trPr><w:cantSplit></w:cantSplit><w:tblHeader></w:tblHeader></w:trPr><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">num</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">char</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"center\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">fctr</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">date</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">time</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">datetime</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">currency</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">row</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">group</w:t>\n  </w:r>\n</w:p></w:tc></w:tr><w:tr><w:trPr><w:cantSplit></w:cantSplit></w:trPr><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">0.1111</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">apricot</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"center\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">one</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">2015-01-15</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">13:35</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">2018-01-01 02:22</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">49.95</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">row_1</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">grp_a</w:t>\n  </w:r>\n</w:p></w:tc></w:tr></w:tbl><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"start\"/>\n    <w:pStyle w:val=\"caption\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"24\"/>\n    </w:rPr>\n    <w:t xml:space=\"preserve\">Table </w:t>\n  </w:r>\n  <w:r>\n    <w:fldChar w:fldCharType=\"begin\" w:dirty=\"true\"/>\n  </w:r>\n  <w:r>\n    <w:instrText xml:space=\"preserve\" w:dirty=\"true\"> SEQ Table \\* ARABIC </w:instrText>\n  </w:r>\n  <w:r>\n    <w:fldChar w:fldCharType=\"separate\" w:dirty=\"true\"/>\n  </w:r>\n  <w:r>\n    <w:rPr>\n      <w:noProof/>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"24\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">1</w:t>\n  </w:r>\n  <w:r>\n    <w:fldChar w:fldCharType=\"end\" w:dirty=\"true\"/>\n  </w:r>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"24\"/>\n    </w:rPr>\n    <w:t xml:space=\"preserve\">: </w:t>\n  </w:r>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"24\"/>\n      <w:color w:val=\"333333\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">TABLE TITLE</w:t>\n  </w:r>\n</w:p><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"start\"/>\n    <w:pStyle w:val=\"caption\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n      <w:color w:val=\"333333\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">table subtitle</w:t>\n  </w:r>\n</w:p>"

---

    Code
      as_word(gt_tbl, ...)
    Output
      [1] "<w:tbl xmlns:w=\"http://schemas.openxmlformats.org/wordprocessingml/2006/main\" xmlns:wp=\"http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing\" xmlns:r=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships\" xmlns:w14=\"http://schemas.microsoft.com/office/word/2010/wordml\"><w:tblPr><w:tblCellMar><w:top w:w=\"0\" w:type=\"dxa\"></w:top><w:bottom w:w=\"0\" w:type=\"dxa\"></w:bottom><w:start w:w=\"60\" w:type=\"dxa\"></w:start><w:end w:w=\"60\" w:type=\"dxa\"></w:end></w:tblCellMar><w:tblW w:type=\"auto\" w:w=\"0\"></w:tblW><w:tblLook w:firstRow=\"0\" w:lastRow=\"0\" w:firstColumn=\"0\" w:lastColumn=\"0\" w:noHBand=\"0\" w:noVBand=\"0\"></w:tblLook><w:jc w:val=\"center\"></w:jc></w:tblPr><w:tr><w:trPr><w:cantSplit></w:cantSplit><w:tblHeader></w:tblHeader></w:trPr><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top></w:tcBorders><w:gridSpan w:val=\"9\"/></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"center\"/>\n    <w:pStyle w:val=\"caption\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"24\"/>\n      <w:color w:val=\"333333\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">TABLE TITLE</w:t>\n  </w:r>\n</w:p><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"center\"/>\n    <w:pStyle w:val=\"caption\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts/>\n      <w:sz w:val=\"16\"/>\n      <w:color w:val=\"333333\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">table subtitle</w:t>\n  </w:r>\n</w:p></w:tc></w:tr><w:tr><w:trPr><w:cantSplit></w:cantSplit><w:tblHeader></w:tblHeader></w:trPr><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">num</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">char</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"center\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">fctr</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">date</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">time</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">datetime</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">currency</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">row</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">group</w:t>\n  </w:r>\n</w:p></w:tc></w:tr><w:tr><w:trPr><w:cantSplit></w:cantSplit></w:trPr><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">0.1111</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">apricot</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"center\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">one</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">2015-01-15</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">13:35</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">2018-01-01 02:22</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">49.95</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">row_1</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">grp_a</w:t>\n  </w:r>\n</w:p></w:tc></w:tr></w:tbl>"

---

    Code
      as_word(gt_tbl, ...)
    Output
      [1] "<w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n    <w:pStyle w:val=\"caption\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"24\"/>\n    </w:rPr>\n    <w:t xml:space=\"preserve\">Table </w:t>\n  </w:r>\n  <w:r>\n    <w:fldChar w:fldCharType=\"begin\" w:dirty=\"true\"/>\n  </w:r>\n  <w:r>\n    <w:instrText xml:space=\"preserve\" w:dirty=\"true\"> SEQ Table \\* ARABIC </w:instrText>\n  </w:r>\n  <w:r>\n    <w:fldChar w:fldCharType=\"separate\" w:dirty=\"true\"/>\n  </w:r>\n  <w:r>\n    <w:rPr>\n      <w:noProof/>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"24\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">1</w:t>\n  </w:r>\n  <w:r>\n    <w:fldChar w:fldCharType=\"end\" w:dirty=\"true\"/>\n  </w:r>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"24\"/>\n    </w:rPr>\n    <w:t xml:space=\"preserve\">: </w:t>\n  </w:r>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"24\"/>\n      <w:color w:val=\"333333\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">TABLE TITLE</w:t>\n  </w:r>\n</w:p><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n    <w:pStyle w:val=\"caption\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n      <w:color w:val=\"333333\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">table subtitle</w:t>\n  </w:r>\n</w:p><w:tbl xmlns:w=\"http://schemas.openxmlformats.org/wordprocessingml/2006/main\" xmlns:wp=\"http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing\" xmlns:r=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships\" xmlns:w14=\"http://schemas.microsoft.com/office/word/2010/wordml\"><w:tblPr><w:tblCellMar><w:top w:w=\"0\" w:type=\"dxa\"></w:top><w:bottom w:w=\"0\" w:type=\"dxa\"></w:bottom><w:start w:w=\"60\" w:type=\"dxa\"></w:start><w:end w:w=\"60\" w:type=\"dxa\"></w:end></w:tblCellMar><w:tblW w:type=\"auto\" w:w=\"0\"></w:tblW><w:tblLook w:firstRow=\"0\" w:lastRow=\"0\" w:firstColumn=\"0\" w:lastColumn=\"0\" w:noHBand=\"0\" w:noVBand=\"0\"></w:tblLook><w:jc w:val=\"center\"></w:jc></w:tblPr><w:tr><w:trPr><w:tblHeader></w:tblHeader></w:trPr><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">num</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">char</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"center\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">fctr</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">date</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">time</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">datetime</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">currency</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">row</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">group</w:t>\n  </w:r>\n</w:p></w:tc></w:tr><w:tr><w:trPr></w:trPr><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">0.1111</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">apricot</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"center\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">one</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">2015-01-15</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">13:35</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">2018-01-01 02:22</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">49.95</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">row_1</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">grp_a</w:t>\n  </w:r>\n</w:p></w:tc></w:tr></w:tbl>"

---

    Code
      as_word(gt_tbl, ...)
    Output
      [1] "<w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"start\"/>\n    <w:pStyle w:val=\"caption\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"24\"/>\n    </w:rPr>\n    <w:t xml:space=\"preserve\">Table </w:t>\n  </w:r>\n  <w:r>\n    <w:fldChar w:fldCharType=\"begin\" w:dirty=\"true\"/>\n  </w:r>\n  <w:r>\n    <w:instrText xml:space=\"preserve\" w:dirty=\"true\"> SEQ Table \\* ARABIC </w:instrText>\n  </w:r>\n  <w:r>\n    <w:fldChar w:fldCharType=\"separate\" w:dirty=\"true\"/>\n  </w:r>\n  <w:r>\n    <w:rPr>\n      <w:noProof/>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"24\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">1</w:t>\n  </w:r>\n  <w:r>\n    <w:fldChar w:fldCharType=\"end\" w:dirty=\"true\"/>\n  </w:r>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"24\"/>\n    </w:rPr>\n    <w:t xml:space=\"preserve\">: </w:t>\n  </w:r>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"24\"/>\n      <w:color w:val=\"333333\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">TABLE TITLE</w:t>\n  </w:r>\n</w:p><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"start\"/>\n    <w:pStyle w:val=\"caption\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n      <w:color w:val=\"333333\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">table subtitle</w:t>\n  </w:r>\n</w:p><w:tbl xmlns:w=\"http://schemas.openxmlformats.org/wordprocessingml/2006/main\" xmlns:wp=\"http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing\" xmlns:r=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships\" xmlns:w14=\"http://schemas.microsoft.com/office/word/2010/wordml\"><w:tblPr><w:tblCellMar><w:top w:w=\"0\" w:type=\"dxa\"></w:top><w:bottom w:w=\"0\" w:type=\"dxa\"></w:bottom><w:start w:w=\"60\" w:type=\"dxa\"></w:start><w:end w:w=\"60\" w:type=\"dxa\"></w:end></w:tblCellMar><w:tblW w:type=\"auto\" w:w=\"0\"></w:tblW><w:tblLook w:firstRow=\"0\" w:lastRow=\"0\" w:firstColumn=\"0\" w:lastColumn=\"0\" w:noHBand=\"0\" w:noVBand=\"0\"></w:tblLook><w:jc w:val=\"center\"></w:jc></w:tblPr><w:tr><w:trPr><w:cantSplit></w:cantSplit><w:tblHeader></w:tblHeader></w:trPr><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">num</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">char</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"center\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">fctr</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">date</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">time</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">datetime</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">currency</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">row</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">group</w:t>\n  </w:r>\n</w:p></w:tc></w:tr><w:tr><w:trPr><w:cantSplit></w:cantSplit></w:trPr><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">0.1111</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">apricot</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"center\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">one</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">2015-01-15</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">13:35</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">2018-01-01 02:22</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">49.95</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">row_1</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">grp_a</w:t>\n  </w:r>\n</w:p></w:tc></w:tr></w:tbl>"

---

    Code
      as_word(gt_tbl, ...)
    Output
      [1] "<w:tbl xmlns:w=\"http://schemas.openxmlformats.org/wordprocessingml/2006/main\" xmlns:wp=\"http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing\" xmlns:r=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships\" xmlns:w14=\"http://schemas.microsoft.com/office/word/2010/wordml\"><w:tblPr><w:tblCellMar><w:top w:w=\"0\" w:type=\"dxa\"></w:top><w:bottom w:w=\"0\" w:type=\"dxa\"></w:bottom><w:start w:w=\"60\" w:type=\"dxa\"></w:start><w:end w:w=\"60\" w:type=\"dxa\"></w:end></w:tblCellMar><w:tblW w:type=\"auto\" w:w=\"0\"></w:tblW><w:tblLook w:firstRow=\"0\" w:lastRow=\"0\" w:firstColumn=\"0\" w:lastColumn=\"0\" w:noHBand=\"0\" w:noVBand=\"0\"></w:tblLook><w:jc w:val=\"center\"></w:jc></w:tblPr><w:tr><w:trPr><w:cantSplit></w:cantSplit><w:tblHeader></w:tblHeader></w:trPr><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\"/>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">num</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"center\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">fctr</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">date</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">time</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">datetime</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">currency</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">row</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">group</w:t>\n  </w:r>\n</w:p></w:tc></w:tr><w:tr><w:trPr><w:cantSplit></w:cantSplit></w:trPr><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders><w:tcMar><w:top w:w=\"25\" w:type=\"dxa\"></w:top></w:tcMar><w:gridSpan w:val=\"9\"/></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n      <w:color w:val=\"0000FF\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">My Row Group 2</w:t>\n  </w:r>\n</w:p></w:tc></w:tr>\n<w:tr><w:trPr><w:cantSplit></w:cantSplit></w:trPr><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Biome\" w:hAnsi=\"Biome\"/>\n      <w:sz w:val=\"20\"/>\n      <w:color w:val=\"00FF00\"/>\n      <w:i/>\n      <w:b w:val=\"true\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">coconut</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders><w:shd w:val=\"clear\" w:color=\"auto\" w:fill=\"FFA500\"></w:shd></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">33.3300</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders><w:shd w:val=\"clear\" w:color=\"auto\" w:fill=\"FFA500\"></w:shd></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"center\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">three</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">2015-03-15</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders><w:shd w:val=\"clear\" w:color=\"auto\" w:fill=\"FFA500\"></w:shd></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">15:45</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">2018-03-03 03:44</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders><w:shd w:val=\"clear\" w:color=\"auto\" w:fill=\"FFA500\"></w:shd></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">1.39</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">row_3</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders><w:shd w:val=\"clear\" w:color=\"auto\" w:fill=\"FFA500\"></w:shd></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">grp_a</w:t>\n  </w:r>\n</w:p></w:tc></w:tr>\n<w:tr><w:trPr><w:cantSplit></w:cantSplit></w:trPr><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Biome\" w:hAnsi=\"Biome\"/>\n      <w:sz w:val=\"20\"/>\n      <w:color w:val=\"00FF00\"/>\n      <w:i/>\n      <w:b w:val=\"true\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">durian</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders><w:shd w:val=\"clear\" w:color=\"auto\" w:fill=\"FFA500\"></w:shd></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">444.4000</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders><w:shd w:val=\"clear\" w:color=\"auto\" w:fill=\"FFA500\"></w:shd></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"center\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">four</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">2015-04-15</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders><w:shd w:val=\"clear\" w:color=\"auto\" w:fill=\"FFA500\"></w:shd></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">16:50</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">2018-04-04 15:55</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders><w:shd w:val=\"clear\" w:color=\"auto\" w:fill=\"FFA500\"></w:shd></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">65100.00</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">row_4</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders><w:shd w:val=\"clear\" w:color=\"auto\" w:fill=\"FFA500\"></w:shd></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">grp_a</w:t>\n  </w:r>\n</w:p></w:tc></w:tr>\n<w:tr><w:trPr><w:cantSplit></w:cantSplit></w:trPr><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders><w:tcMar><w:top w:w=\"25\" w:type=\"dxa\"></w:top></w:tcMar><w:gridSpan w:val=\"9\"/></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n      <w:color w:val=\"0000FF\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">My Row Group 1</w:t>\n  </w:r>\n</w:p></w:tc></w:tr>\n<w:tr><w:trPr><w:cantSplit></w:cantSplit></w:trPr><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Biome\" w:hAnsi=\"Biome\"/>\n      <w:sz w:val=\"20\"/>\n      <w:color w:val=\"00FF00\"/>\n      <w:i/>\n      <w:b w:val=\"true\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">apricot</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders><w:shd w:val=\"clear\" w:color=\"auto\" w:fill=\"FFA500\"></w:shd></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">0.1111</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders><w:shd w:val=\"clear\" w:color=\"auto\" w:fill=\"FFA500\"></w:shd></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"center\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">one</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">2015-01-15</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders><w:shd w:val=\"clear\" w:color=\"auto\" w:fill=\"FFA500\"></w:shd></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">13:35</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">2018-01-01 02:22</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders><w:shd w:val=\"clear\" w:color=\"auto\" w:fill=\"FFA500\"></w:shd></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">49.95</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">row_1</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders><w:shd w:val=\"clear\" w:color=\"auto\" w:fill=\"FFA500\"></w:shd></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">grp_a</w:t>\n  </w:r>\n</w:p></w:tc></w:tr>\n<w:tr><w:trPr><w:cantSplit></w:cantSplit></w:trPr><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Biome\" w:hAnsi=\"Biome\"/>\n      <w:sz w:val=\"20\"/>\n      <w:color w:val=\"00FF00\"/>\n      <w:i/>\n      <w:b w:val=\"true\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">banana</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders><w:shd w:val=\"clear\" w:color=\"auto\" w:fill=\"FFA500\"></w:shd></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">2.2220</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders><w:shd w:val=\"clear\" w:color=\"auto\" w:fill=\"FFA500\"></w:shd></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"center\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">two</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">2015-02-15</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders><w:shd w:val=\"clear\" w:color=\"auto\" w:fill=\"FFA500\"></w:shd></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">14:40</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">2018-02-02 14:33</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders><w:shd w:val=\"clear\" w:color=\"auto\" w:fill=\"FFA500\"></w:shd></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">17.95</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">row_2</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders><w:shd w:val=\"clear\" w:color=\"auto\" w:fill=\"FFA500\"></w:shd></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">grp_a</w:t>\n  </w:r>\n</w:p></w:tc></w:tr></w:tbl>"

# word ooxml escapes special characters in gt object

    Code
      as_word(gt_tbl, ...)
    Output
      [1] "<w:tbl xmlns:w=\"http://schemas.openxmlformats.org/wordprocessingml/2006/main\" xmlns:wp=\"http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing\" xmlns:r=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships\" xmlns:w14=\"http://schemas.microsoft.com/office/word/2010/wordml\"><w:tblPr><w:tblCellMar><w:top w:w=\"0\" w:type=\"dxa\"></w:top><w:bottom w:w=\"0\" w:type=\"dxa\"></w:bottom><w:start w:w=\"60\" w:type=\"dxa\"></w:start><w:end w:w=\"60\" w:type=\"dxa\"></w:end></w:tblCellMar><w:tblW w:type=\"auto\" w:w=\"0\"></w:tblW><w:tblLook w:firstRow=\"0\" w:lastRow=\"0\" w:firstColumn=\"0\" w:lastColumn=\"0\" w:noHBand=\"0\" w:noVBand=\"0\"></w:tblLook><w:jc w:val=\"center\"></w:jc></w:tblPr><w:tr><w:trPr><w:cantSplit></w:cantSplit><w:tblHeader></w:tblHeader></w:trPr><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">num</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">char</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"center\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">fctr</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">date</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">time</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">datetime</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">currency</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">row</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">group</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">special_characters</w:t>\n  </w:r>\n</w:p></w:tc></w:tr><w:tr><w:trPr><w:cantSplit></w:cantSplit></w:trPr><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">0.1111</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">apricot</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"center\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">one</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">2015-01-15</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">13:35</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">2018-01-01 02:22</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">49.95</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">row_1</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">grp_a</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">&gt;&lt;&amp; \"'</w:t>\n  </w:r>\n</w:p></w:tc></w:tr></w:tbl>"

# word ooxml escapes special characters in gt object footer

    Code
      as_word(gt_tbl, ...)
    Output
      [1] "<w:tbl xmlns:w=\"http://schemas.openxmlformats.org/wordprocessingml/2006/main\" xmlns:wp=\"http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing\" xmlns:r=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships\" xmlns:w14=\"http://schemas.microsoft.com/office/word/2010/wordml\"><w:tblPr><w:tblCellMar><w:top w:w=\"0\" w:type=\"dxa\"></w:top><w:bottom w:w=\"0\" w:type=\"dxa\"></w:bottom><w:start w:w=\"60\" w:type=\"dxa\"></w:start><w:end w:w=\"60\" w:type=\"dxa\"></w:end></w:tblCellMar><w:tblW w:type=\"auto\" w:w=\"0\"></w:tblW><w:tblLook w:firstRow=\"0\" w:lastRow=\"0\" w:firstColumn=\"0\" w:lastColumn=\"0\" w:noHBand=\"0\" w:noVBand=\"0\"></w:tblLook><w:jc w:val=\"center\"></w:jc></w:tblPr><w:tr><w:trPr><w:cantSplit></w:cantSplit><w:tblHeader></w:tblHeader></w:trPr><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">num</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">char</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"center\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">fctr</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">date</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">time</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">datetime</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">currency</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">row</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">group</w:t>\n  </w:r>\n</w:p></w:tc></w:tr><w:tr><w:trPr><w:cantSplit></w:cantSplit></w:trPr><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">0.1111</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">apricot</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"center\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">one</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">2015-01-15</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">13:35</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">2018-01-01 02:22</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"end\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">49.95</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">row_1</w:t>\n  </w:r>\n</w:p></w:tc><w:tc><w:tcPr><w:tcBorders><w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:top><w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:bottom><w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:start><w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"></w:end></w:tcBorders></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n    <w:jc w:val=\"start\"/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">grp_a</w:t>\n  </w:r>\n</w:p></w:tc></w:tr><w:tr><w:trPr><w:cantSplit></w:cantSplit></w:trPr><w:tc><w:tcPr><w:gridSpan w:val=\"9\"/></w:tcPr><w:p>\n  <w:pPr>\n    <w:spacing w:before=\"0\" w:after=\"60\"/>\n    <w:keepNext/>\n  </w:pPr>\n  <w:r>\n    <w:rPr>\n      <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n      <w:sz w:val=\"20\"/>\n    </w:rPr>\n    <w:t xml:space=\"default\">p &lt; .05, &gt;&lt;&amp; \"'</w:t>\n  </w:r>\n</w:p></w:tc></w:tr></w:tbl>"

