# gtsave() errors with bad filename input

    Code
      gtsave(gt(exibble), filename = "exibble.bat")
    Condition
      Error in `gtsave()`:
      ! The file extension supplied (`.bat`) cannot be used.
      i We can use:
      * `.html`, `.htm` (HTML file)
      * `.png` (PNG file)
      * `.pdf` (PDF file)
      * `.tex`, `.rnw` (LaTeX file)
      * `.rtf` (RTF file)
      * `.docx` (Word file)
    Code
      gtsave(gt(exibble), filename = "exibble")
    Condition
      Error in `gtsave()`:
      ! A file extension is required in the provided filename.
      i We can use:
      * `.html`, `.htm` (HTML file)
      * `.png` (PNG file)
      * `.pdf` (PDF file)
      * `.tex`, `.rnw` (LaTeX file)
      * `.rtf` (RTF file)
      * `.docx` (Word file)

# gtsave() creates docx files as expected

    Code
      .
    Output
      [1] "<w:tbl xmlns:w=\"http://schemas.openxmlformats.org/wordprocessingml/2006/main\" xmlns:wp=\"http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing\" xmlns:r=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships\" xmlns:w14=\"http://schemas.microsoft.com/office/word/2010/wordml\">\n  <w:tblPr>\n    <w:tblCellMar>\n      <w:top w:w=\"0\" w:type=\"dxa\"/>\n      <w:bottom w:w=\"0\" w:type=\"dxa\"/>\n      <w:start w:w=\"60\" w:type=\"dxa\"/>\n      <w:end w:w=\"60\" w:type=\"dxa\"/>\n    </w:tblCellMar>\n    <w:tblW w:type=\"auto\" w:w=\"0\"/>\n    <w:tblLook w:firstRow=\"0\" w:lastRow=\"0\" w:firstColumn=\"0\" w:lastColumn=\"0\" w:noHBand=\"0\" w:noVBand=\"0\"/>\n    <w:jc w:val=\"center\"/>\n  </w:tblPr>\n  <w:tr>\n    <w:trPr>\n      <w:cantSplit/>\n      <w:tblHeader/>\n    </w:trPr>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">num</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"start\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">char</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"center\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">fctr</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">date</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">time</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">datetime</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">currency</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"start\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">row</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"start\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">group</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n  </w:tr>\n  <w:tr>\n    <w:trPr>\n      <w:cantSplit/>\n    </w:trPr>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">1.111e-01</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"start\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">apricot</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"center\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">one</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">2015-01-15</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">13:35</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">2018-01-01 02:22</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">49.950</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"start\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">row_1</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"start\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">grp_a</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n  </w:tr>\n  <w:tr>\n    <w:trPr>\n      <w:cantSplit/>\n    </w:trPr>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">2.222e+00</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"start\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">banana</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"center\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">two</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">2015-02-15</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">14:40</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">2018-02-02 14:33</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">17.950</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"start\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">row_2</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"start\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">grp_a</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n  </w:tr>\n  <w:tr>\n    <w:trPr>\n      <w:cantSplit/>\n    </w:trPr>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">3.333e+01</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"start\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">coconut</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"center\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">three</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">2015-03-15</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">15:45</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">2018-03-03 03:44</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">1.390</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"start\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">row_3</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"start\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">grp_a</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n  </w:tr>\n  <w:tr>\n    <w:trPr>\n      <w:cantSplit/>\n    </w:trPr>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">4.444e+02</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"start\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">durian</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"center\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">four</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">2015-04-15</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">16:50</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">2018-04-04 15:55</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">65100.000</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"start\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">row_4</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"start\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">grp_a</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n  </w:tr>\n  <w:tr>\n    <w:trPr>\n      <w:cantSplit/>\n    </w:trPr>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">5.550e+03</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"start\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">NA</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"center\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">five</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">2015-05-15</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">17:55</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">2018-05-05 04:00</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">1325.810</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"start\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">row_5</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"start\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">grp_b</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n  </w:tr>\n  <w:tr>\n    <w:trPr>\n      <w:cantSplit/>\n    </w:trPr>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">NA</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"start\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">fig</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"center\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">six</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">2015-06-15</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">NA</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">2018-06-06 16:11</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">13.255</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"start\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">row_6</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"start\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">grp_b</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n  </w:tr>\n  <w:tr>\n    <w:trPr>\n      <w:cantSplit/>\n    </w:trPr>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">7.770e+05</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"start\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">grapefruit</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"center\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">seven</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">NA</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">19:10</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">2018-07-07 05:22</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">NA</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"start\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">row_7</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"start\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">grp_b</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n  </w:tr>\n  <w:tr>\n    <w:trPr>\n      <w:cantSplit/>\n    </w:trPr>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">8.880e+06</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"start\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">honeydew</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"center\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">eight</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">2015-08-15</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">20:20</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">NA</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">0.440</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"start\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">row_8</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"start\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">grp_b</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n  </w:tr>\n</w:tbl>"

# gtsave() creates docx files when a table has special characters (#121)

    Code
      temp_docx_out
    Output
      [1] "<w:tbl xmlns:w=\"http://schemas.openxmlformats.org/wordprocessingml/2006/main\" xmlns:wp=\"http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing\" xmlns:r=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships\" xmlns:w14=\"http://schemas.microsoft.com/office/word/2010/wordml\">\n  <w:tblPr>\n    <w:tblCellMar>\n      <w:top w:w=\"0\" w:type=\"dxa\"/>\n      <w:bottom w:w=\"0\" w:type=\"dxa\"/>\n      <w:start w:w=\"60\" w:type=\"dxa\"/>\n      <w:end w:w=\"60\" w:type=\"dxa\"/>\n    </w:tblCellMar>\n    <w:tblW w:type=\"auto\" w:w=\"0\"/>\n    <w:tblLook w:firstRow=\"0\" w:lastRow=\"0\" w:firstColumn=\"0\" w:lastColumn=\"0\" w:noHBand=\"0\" w:noVBand=\"0\"/>\n    <w:jc w:val=\"center\"/>\n  </w:tblPr>\n  <w:tr>\n    <w:trPr>\n      <w:cantSplit/>\n      <w:tblHeader/>\n    </w:trPr>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"start\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">a</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:sz=\"16\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">b</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n  </w:tr>\n  <w:tr>\n    <w:trPr>\n      <w:cantSplit/>\n    </w:trPr>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"start\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">&lt;</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">1</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n  </w:tr>\n  <w:tr>\n    <w:trPr>\n      <w:cantSplit/>\n    </w:trPr>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"start\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">b</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n    <w:tc>\n      <w:tcPr>\n        <w:tcBorders>\n          <w:top w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:bottom w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:start w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n          <w:end w:val=\"single\" w:space=\"0\" w:color=\"D3D3D3\"/>\n        </w:tcBorders>\n      </w:tcPr>\n      <w:p>\n        <w:pPr>\n          <w:spacing w:before=\"0\" w:after=\"60\"/>\n          <w:keepNext/>\n          <w:jc w:val=\"end\"/>\n        </w:pPr>\n        <w:r>\n          <w:rPr>\n            <w:rFonts w:ascii=\"Calibri\" w:hAnsi=\"Calibri\"/>\n            <w:sz w:val=\"20\"/>\n          </w:rPr>\n          <w:t xml:space=\"default\">2</w:t>\n        </w:r>\n      </w:p>\n    </w:tc>\n  </w:tr>\n</w:tbl>"

