---
title: "latex-03-pressure"
output: 
  - pdf_document
---

```{r setup, include=FALSE}
knitr::opts_chunk$set(echo = TRUE)
library(gt)
```

Create a display table based on `pressure`.

```{r}
gt(pressure) %>%
  fmt_scientific(
    columns = pressure,
    decimals = 2
  )
```
