# gt_tbls can be rendered as a gtable

    Code
      gtable$layout
    Output
          t l  b r  z clip            name
      1   1 2  1 5  1  off         caption
      2   2 2  2 5  2  off           title
      3   3 2  4 3  3  off        stubhead
      4   3 4  3 5  4  off         spanner
      5   4 4  4 4  5  off  column_label_1
      6   4 5  4 5  6  off  column_label_2
      7   5 3  5 3  7  off group_summary_1
      8   5 4  5 4  8  off group_summary_2
      9   5 5  5 5  9  off group_summary_3
      10  5 2 10 2 10  off     body_cell_1
      11  6 3  6 3 11  off     body_cell_2
      12  6 4  6 4 12  off     body_cell_3
      13  6 5  6 5 13  off     body_cell_4
      14  7 3  7 3 14  off     body_cell_5
      15  7 4  7 4 15  off     body_cell_6
      16  7 5  7 5 16  off     body_cell_7
      17  8 3  8 3 17  off     body_cell_8
      18  8 4  8 4 18  off     body_cell_9
      19  8 5  8 5 19  off    body_cell_10
      20  9 3  9 3 20  off    body_cell_11
      21  9 4  9 4 21  off    body_cell_12
      22  9 5  9 5 22  off    body_cell_13
      23 10 3 10 3 23  off    body_cell_14
      24 10 4 10 4 24  off    body_cell_15
      25 10 5 10 5 25  off    body_cell_16
      26 11 3 11 3 26  off group_summary_4
      27 11 4 11 4 27  off group_summary_5
      28 11 5 11 5 28  off group_summary_6
      29 11 2 14 2 29  off    body_cell_17
      30 12 3 12 3 30  off    body_cell_18
      31 12 4 12 4 31  off    body_cell_19
      32 12 5 12 5 32  off    body_cell_20
      33 13 3 13 3 33  off    body_cell_21
      34 13 4 13 4 34  off    body_cell_22
      35 13 5 13 5 35  off    body_cell_23
      36 14 3 14 3 36  off    body_cell_24
      37 14 4 14 4 37  off    body_cell_25
      38 14 5 14 5 38  off    body_cell_26
      39 15 2 15 3 39  off grand_summary_1
      40 15 4 15 4 40  off grand_summary_2
      41 15 5 15 5 41  off grand_summary_3
      42 17 2 17 5 42  off    source_notes
      43 16 2 16 5 43  off       footnotes
      44  5 2 15 5 44  off      table_body
      45  2 2 17 5 45  off           table

