# get_image_uri() works correctly

    Code
      get_image_uri(file = test_image(type = "png"))
    Output
      [1] "data:image/png;base64,[encoded data, 46292 characters]"

# local_image() works correctly

    Code
      local_image(filename = test_image(type = "png"))
    Output
      [1] "<img src=\"data:image/png;base64,[encoded data, 46292 characters]\" style=\"height:30px;\">"

---

    Code
      local_image(filename = test_image(type = "svg"))
    Output
      [1] "<img src=\"data:image/svg+xml;base64,[encoded data, 6180 characters]\" style=\"height:30px;\">"

---

    Code
      local_image(filename = rep(test_image(type = "png"), 2))
    Output
      [1] "<img src=\"data:image/png;base64,[encoded data, 46292 characters]\" style=\"height:30px;\">"
      [2] "<img src=\"data:image/png;base64,[encoded data, 46292 characters]\" style=\"height:30px;\">"

# ggplot_image() works correctly

    Code
      ggplot_image(plot_object = gg)
    Output
      [1] "<img src=\"data:image/png;base64,[encoded data, 21936 characters]\" style=\"height:100px;\">"

