# Vertical padding across several table parts can be applied

    Code
      render_as_html(gt_tbl)
    Output
      [1] "<table class=\"gt_table\" data-quarto-disable-processing=\"false\" data-quarto-bootstrap=\"false\">\n  <thead>\n    <tr class=\"gt_heading\">\n      <td colspan=\"12\" class=\"gt_heading gt_title gt_font_normal\" style>The mtcars Dataset<span class=\"gt_footnote_marks\" style=\"white-space:nowrap;font-style:italic;font-weight:normal;line-height:0;\"><sup>1</sup></span></td>\n    </tr>\n    <tr class=\"gt_heading\">\n      <td colspan=\"12\" class=\"gt_heading gt_subtitle gt_font_normal gt_bottom_border\" style>What a great dataset this is</td>\n    </tr>\n    <tr class=\"gt_col_headings gt_spanner_row\">\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_left\" rowspan=\"2\" colspan=\"1\" scope=\"col\" id=\"a::stub\"></th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"2\" colspan=\"1\" scope=\"col\" id=\"mpg\">mpg</th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"2\" colspan=\"1\" scope=\"col\" id=\"cyl\">cyl</th>\n      <th class=\"gt_center gt_columns_top_border gt_column_spanner_outer\" rowspan=\"1\" colspan=\"3\" scope=\"colgroup\" id=\"performance\">\n        <div class=\"gt_column_spanner\">performance</div>\n      </th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"2\" colspan=\"1\" scope=\"col\" id=\"wt\">wt</th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"2\" colspan=\"1\" scope=\"col\" id=\"qsec\">qsec</th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"2\" colspan=\"1\" scope=\"col\" id=\"vs\">vs</th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"2\" colspan=\"1\" scope=\"col\" id=\"am\">am</th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"2\" colspan=\"1\" scope=\"col\" id=\"gear\">gear</th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"2\" colspan=\"1\" scope=\"col\" id=\"carb\">carb</th>\n    </tr>\n    <tr class=\"gt_col_headings\">\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"1\" colspan=\"1\" scope=\"col\" id=\"disp\">disp</th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"1\" colspan=\"1\" scope=\"col\" id=\"hp\">hp</th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"1\" colspan=\"1\" scope=\"col\" id=\"drat\">drat</th>\n    </tr>\n  </thead>\n  <tbody class=\"gt_table_body\">\n    <tr><th id=\"stub_1_1\" scope=\"row\" class=\"gt_row gt_left gt_stub\">Mazda RX4</th>\n<td headers=\"stub_1_1 mpg\" class=\"gt_row gt_right\">21.0</td>\n<td headers=\"stub_1_1 cyl\" class=\"gt_row gt_right\">6</td>\n<td headers=\"stub_1_1 disp\" class=\"gt_row gt_right\">160</td>\n<td headers=\"stub_1_1 hp\" class=\"gt_row gt_right\">110</td>\n<td headers=\"stub_1_1 drat\" class=\"gt_row gt_right\">3.90</td>\n<td headers=\"stub_1_1 wt\" class=\"gt_row gt_right\">2.620</td>\n<td headers=\"stub_1_1 qsec\" class=\"gt_row gt_right\">16.46</td>\n<td headers=\"stub_1_1 vs\" class=\"gt_row gt_right\">0</td>\n<td headers=\"stub_1_1 am\" class=\"gt_row gt_right\">1</td>\n<td headers=\"stub_1_1 gear\" class=\"gt_row gt_right\">4</td>\n<td headers=\"stub_1_1 carb\" class=\"gt_row gt_right\">4</td></tr>\n    <tr><th id=\"stub_1_2\" scope=\"row\" class=\"gt_row gt_left gt_stub\">Mazda RX4 Wag</th>\n<td headers=\"stub_1_2 mpg\" class=\"gt_row gt_right\">21.0</td>\n<td headers=\"stub_1_2 cyl\" class=\"gt_row gt_right\">6</td>\n<td headers=\"stub_1_2 disp\" class=\"gt_row gt_right\">160</td>\n<td headers=\"stub_1_2 hp\" class=\"gt_row gt_right\">110</td>\n<td headers=\"stub_1_2 drat\" class=\"gt_row gt_right\">3.90</td>\n<td headers=\"stub_1_2 wt\" class=\"gt_row gt_right\">2.875</td>\n<td headers=\"stub_1_2 qsec\" class=\"gt_row gt_right\">17.02</td>\n<td headers=\"stub_1_2 vs\" class=\"gt_row gt_right\">0</td>\n<td headers=\"stub_1_2 am\" class=\"gt_row gt_right\">1</td>\n<td headers=\"stub_1_2 gear\" class=\"gt_row gt_right\">4</td>\n<td headers=\"stub_1_2 carb\" class=\"gt_row gt_right\">4</td></tr>\n    <tr><th id=\"stub_1_3\" scope=\"row\" class=\"gt_row gt_left gt_stub\">Datsun 710</th>\n<td headers=\"stub_1_3 mpg\" class=\"gt_row gt_right\">22.8</td>\n<td headers=\"stub_1_3 cyl\" class=\"gt_row gt_right\">4</td>\n<td headers=\"stub_1_3 disp\" class=\"gt_row gt_right\">108</td>\n<td headers=\"stub_1_3 hp\" class=\"gt_row gt_right\">93</td>\n<td headers=\"stub_1_3 drat\" class=\"gt_row gt_right\">3.85</td>\n<td headers=\"stub_1_3 wt\" class=\"gt_row gt_right\">2.320</td>\n<td headers=\"stub_1_3 qsec\" class=\"gt_row gt_right\">18.61</td>\n<td headers=\"stub_1_3 vs\" class=\"gt_row gt_right\">1</td>\n<td headers=\"stub_1_3 am\" class=\"gt_row gt_right\">1</td>\n<td headers=\"stub_1_3 gear\" class=\"gt_row gt_right\">4</td>\n<td headers=\"stub_1_3 carb\" class=\"gt_row gt_right\">1</td></tr>\n    <tr><th id=\"stub_1_4\" scope=\"row\" class=\"gt_row gt_left gt_stub\">Hornet 4 Drive</th>\n<td headers=\"stub_1_4 mpg\" class=\"gt_row gt_right\">21.4</td>\n<td headers=\"stub_1_4 cyl\" class=\"gt_row gt_right\">6</td>\n<td headers=\"stub_1_4 disp\" class=\"gt_row gt_right\">258</td>\n<td headers=\"stub_1_4 hp\" class=\"gt_row gt_right\">110</td>\n<td headers=\"stub_1_4 drat\" class=\"gt_row gt_right\">3.08</td>\n<td headers=\"stub_1_4 wt\" class=\"gt_row gt_right\">3.215</td>\n<td headers=\"stub_1_4 qsec\" class=\"gt_row gt_right\">19.44</td>\n<td headers=\"stub_1_4 vs\" class=\"gt_row gt_right\">1</td>\n<td headers=\"stub_1_4 am\" class=\"gt_row gt_right\">0</td>\n<td headers=\"stub_1_4 gear\" class=\"gt_row gt_right\">3</td>\n<td headers=\"stub_1_4 carb\" class=\"gt_row gt_right\">1</td></tr>\n    <tr><th id=\"stub_1_5\" scope=\"row\" class=\"gt_row gt_left gt_stub\">Hornet Sportabout</th>\n<td headers=\"stub_1_5 mpg\" class=\"gt_row gt_right\">18.7</td>\n<td headers=\"stub_1_5 cyl\" class=\"gt_row gt_right\">8</td>\n<td headers=\"stub_1_5 disp\" class=\"gt_row gt_right\">360</td>\n<td headers=\"stub_1_5 hp\" class=\"gt_row gt_right\">175</td>\n<td headers=\"stub_1_5 drat\" class=\"gt_row gt_right\">3.15</td>\n<td headers=\"stub_1_5 wt\" class=\"gt_row gt_right\">3.440</td>\n<td headers=\"stub_1_5 qsec\" class=\"gt_row gt_right\">17.02</td>\n<td headers=\"stub_1_5 vs\" class=\"gt_row gt_right\">0</td>\n<td headers=\"stub_1_5 am\" class=\"gt_row gt_right\">0</td>\n<td headers=\"stub_1_5 gear\" class=\"gt_row gt_right\">3</td>\n<td headers=\"stub_1_5 carb\" class=\"gt_row gt_right\">2</td></tr>\n  </tbody>\n  <tfoot class=\"gt_sourcenotes\">\n    <tr>\n      <td class=\"gt_sourcenote\" colspan=\"12\">Dataset is generally available in R</td>\n    </tr>\n  </tfoot>\n  <tfoot class=\"gt_footnotes\">\n    <tr>\n      <td class=\"gt_footnote\" colspan=\"12\"><span class=\"gt_footnote_marks\" style=\"white-space:nowrap;font-style:italic;font-weight:normal;line-height:0;\"><sup>1</sup></span> A table footnote</td>\n    </tr>\n  </tfoot>\n</table>"

---

    Code
      render_as_html(gt_tbl)
    Output
      [1] "<table class=\"gt_table\" data-quarto-disable-processing=\"false\" data-quarto-bootstrap=\"false\">\n  <thead>\n    <tr class=\"gt_heading\">\n      <td colspan=\"12\" class=\"gt_heading gt_title gt_font_normal\" style>The mtcars Dataset<span class=\"gt_footnote_marks\" style=\"white-space:nowrap;font-style:italic;font-weight:normal;line-height:0;\"><sup>1</sup></span></td>\n    </tr>\n    <tr class=\"gt_heading\">\n      <td colspan=\"12\" class=\"gt_heading gt_subtitle gt_font_normal gt_bottom_border\" style>What a great dataset this is</td>\n    </tr>\n    <tr class=\"gt_col_headings gt_spanner_row\">\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_left\" rowspan=\"2\" colspan=\"1\" scope=\"col\" id=\"a::stub\"></th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"2\" colspan=\"1\" scope=\"col\" id=\"mpg\">mpg</th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"2\" colspan=\"1\" scope=\"col\" id=\"cyl\">cyl</th>\n      <th class=\"gt_center gt_columns_top_border gt_column_spanner_outer\" rowspan=\"1\" colspan=\"3\" scope=\"colgroup\" id=\"performance\">\n        <div class=\"gt_column_spanner\">performance</div>\n      </th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"2\" colspan=\"1\" scope=\"col\" id=\"wt\">wt</th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"2\" colspan=\"1\" scope=\"col\" id=\"qsec\">qsec</th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"2\" colspan=\"1\" scope=\"col\" id=\"vs\">vs</th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"2\" colspan=\"1\" scope=\"col\" id=\"am\">am</th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"2\" colspan=\"1\" scope=\"col\" id=\"gear\">gear</th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"2\" colspan=\"1\" scope=\"col\" id=\"carb\">carb</th>\n    </tr>\n    <tr class=\"gt_col_headings\">\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"1\" colspan=\"1\" scope=\"col\" id=\"disp\">disp</th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"1\" colspan=\"1\" scope=\"col\" id=\"hp\">hp</th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"1\" colspan=\"1\" scope=\"col\" id=\"drat\">drat</th>\n    </tr>\n  </thead>\n  <tbody class=\"gt_table_body\">\n    <tr><th id=\"stub_1_1\" scope=\"row\" class=\"gt_row gt_left gt_stub\">Mazda RX4</th>\n<td headers=\"stub_1_1 mpg\" class=\"gt_row gt_right\">21.0</td>\n<td headers=\"stub_1_1 cyl\" class=\"gt_row gt_right\">6</td>\n<td headers=\"stub_1_1 disp\" class=\"gt_row gt_right\">160</td>\n<td headers=\"stub_1_1 hp\" class=\"gt_row gt_right\">110</td>\n<td headers=\"stub_1_1 drat\" class=\"gt_row gt_right\">3.90</td>\n<td headers=\"stub_1_1 wt\" class=\"gt_row gt_right\">2.620</td>\n<td headers=\"stub_1_1 qsec\" class=\"gt_row gt_right\">16.46</td>\n<td headers=\"stub_1_1 vs\" class=\"gt_row gt_right\">0</td>\n<td headers=\"stub_1_1 am\" class=\"gt_row gt_right\">1</td>\n<td headers=\"stub_1_1 gear\" class=\"gt_row gt_right\">4</td>\n<td headers=\"stub_1_1 carb\" class=\"gt_row gt_right\">4</td></tr>\n    <tr><th id=\"stub_1_2\" scope=\"row\" class=\"gt_row gt_left gt_stub\">Mazda RX4 Wag</th>\n<td headers=\"stub_1_2 mpg\" class=\"gt_row gt_right\">21.0</td>\n<td headers=\"stub_1_2 cyl\" class=\"gt_row gt_right\">6</td>\n<td headers=\"stub_1_2 disp\" class=\"gt_row gt_right\">160</td>\n<td headers=\"stub_1_2 hp\" class=\"gt_row gt_right\">110</td>\n<td headers=\"stub_1_2 drat\" class=\"gt_row gt_right\">3.90</td>\n<td headers=\"stub_1_2 wt\" class=\"gt_row gt_right\">2.875</td>\n<td headers=\"stub_1_2 qsec\" class=\"gt_row gt_right\">17.02</td>\n<td headers=\"stub_1_2 vs\" class=\"gt_row gt_right\">0</td>\n<td headers=\"stub_1_2 am\" class=\"gt_row gt_right\">1</td>\n<td headers=\"stub_1_2 gear\" class=\"gt_row gt_right\">4</td>\n<td headers=\"stub_1_2 carb\" class=\"gt_row gt_right\">4</td></tr>\n    <tr><th id=\"stub_1_3\" scope=\"row\" class=\"gt_row gt_left gt_stub\">Datsun 710</th>\n<td headers=\"stub_1_3 mpg\" class=\"gt_row gt_right\">22.8</td>\n<td headers=\"stub_1_3 cyl\" class=\"gt_row gt_right\">4</td>\n<td headers=\"stub_1_3 disp\" class=\"gt_row gt_right\">108</td>\n<td headers=\"stub_1_3 hp\" class=\"gt_row gt_right\">93</td>\n<td headers=\"stub_1_3 drat\" class=\"gt_row gt_right\">3.85</td>\n<td headers=\"stub_1_3 wt\" class=\"gt_row gt_right\">2.320</td>\n<td headers=\"stub_1_3 qsec\" class=\"gt_row gt_right\">18.61</td>\n<td headers=\"stub_1_3 vs\" class=\"gt_row gt_right\">1</td>\n<td headers=\"stub_1_3 am\" class=\"gt_row gt_right\">1</td>\n<td headers=\"stub_1_3 gear\" class=\"gt_row gt_right\">4</td>\n<td headers=\"stub_1_3 carb\" class=\"gt_row gt_right\">1</td></tr>\n    <tr><th id=\"stub_1_4\" scope=\"row\" class=\"gt_row gt_left gt_stub\">Hornet 4 Drive</th>\n<td headers=\"stub_1_4 mpg\" class=\"gt_row gt_right\">21.4</td>\n<td headers=\"stub_1_4 cyl\" class=\"gt_row gt_right\">6</td>\n<td headers=\"stub_1_4 disp\" class=\"gt_row gt_right\">258</td>\n<td headers=\"stub_1_4 hp\" class=\"gt_row gt_right\">110</td>\n<td headers=\"stub_1_4 drat\" class=\"gt_row gt_right\">3.08</td>\n<td headers=\"stub_1_4 wt\" class=\"gt_row gt_right\">3.215</td>\n<td headers=\"stub_1_4 qsec\" class=\"gt_row gt_right\">19.44</td>\n<td headers=\"stub_1_4 vs\" class=\"gt_row gt_right\">1</td>\n<td headers=\"stub_1_4 am\" class=\"gt_row gt_right\">0</td>\n<td headers=\"stub_1_4 gear\" class=\"gt_row gt_right\">3</td>\n<td headers=\"stub_1_4 carb\" class=\"gt_row gt_right\">1</td></tr>\n    <tr><th id=\"stub_1_5\" scope=\"row\" class=\"gt_row gt_left gt_stub\">Hornet Sportabout</th>\n<td headers=\"stub_1_5 mpg\" class=\"gt_row gt_right\">18.7</td>\n<td headers=\"stub_1_5 cyl\" class=\"gt_row gt_right\">8</td>\n<td headers=\"stub_1_5 disp\" class=\"gt_row gt_right\">360</td>\n<td headers=\"stub_1_5 hp\" class=\"gt_row gt_right\">175</td>\n<td headers=\"stub_1_5 drat\" class=\"gt_row gt_right\">3.15</td>\n<td headers=\"stub_1_5 wt\" class=\"gt_row gt_right\">3.440</td>\n<td headers=\"stub_1_5 qsec\" class=\"gt_row gt_right\">17.02</td>\n<td headers=\"stub_1_5 vs\" class=\"gt_row gt_right\">0</td>\n<td headers=\"stub_1_5 am\" class=\"gt_row gt_right\">0</td>\n<td headers=\"stub_1_5 gear\" class=\"gt_row gt_right\">3</td>\n<td headers=\"stub_1_5 carb\" class=\"gt_row gt_right\">2</td></tr>\n  </tbody>\n  <tfoot class=\"gt_sourcenotes\">\n    <tr>\n      <td class=\"gt_sourcenote\" colspan=\"12\">Dataset is generally available in R</td>\n    </tr>\n  </tfoot>\n  <tfoot class=\"gt_footnotes\">\n    <tr>\n      <td class=\"gt_footnote\" colspan=\"12\"><span class=\"gt_footnote_marks\" style=\"white-space:nowrap;font-style:italic;font-weight:normal;line-height:0;\"><sup>1</sup></span> A table footnote</td>\n    </tr>\n  </tfoot>\n</table>"

---

    Code
      render_as_html(gt_tbl)
    Output
      [1] "<table class=\"gt_table\" data-quarto-disable-processing=\"false\" data-quarto-bootstrap=\"false\">\n  <thead>\n    <tr class=\"gt_heading\">\n      <td colspan=\"12\" class=\"gt_heading gt_title gt_font_normal\" style>The mtcars Dataset<span class=\"gt_footnote_marks\" style=\"white-space:nowrap;font-style:italic;font-weight:normal;line-height:0;\"><sup>1</sup></span></td>\n    </tr>\n    <tr class=\"gt_heading\">\n      <td colspan=\"12\" class=\"gt_heading gt_subtitle gt_font_normal gt_bottom_border\" style>What a great dataset this is</td>\n    </tr>\n    <tr class=\"gt_col_headings gt_spanner_row\">\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_left\" rowspan=\"2\" colspan=\"1\" scope=\"col\" id=\"a::stub\"></th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"2\" colspan=\"1\" scope=\"col\" id=\"mpg\">mpg</th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"2\" colspan=\"1\" scope=\"col\" id=\"cyl\">cyl</th>\n      <th class=\"gt_center gt_columns_top_border gt_column_spanner_outer\" rowspan=\"1\" colspan=\"3\" scope=\"colgroup\" id=\"performance\">\n        <div class=\"gt_column_spanner\">performance</div>\n      </th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"2\" colspan=\"1\" scope=\"col\" id=\"wt\">wt</th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"2\" colspan=\"1\" scope=\"col\" id=\"qsec\">qsec</th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"2\" colspan=\"1\" scope=\"col\" id=\"vs\">vs</th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"2\" colspan=\"1\" scope=\"col\" id=\"am\">am</th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"2\" colspan=\"1\" scope=\"col\" id=\"gear\">gear</th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"2\" colspan=\"1\" scope=\"col\" id=\"carb\">carb</th>\n    </tr>\n    <tr class=\"gt_col_headings\">\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"1\" colspan=\"1\" scope=\"col\" id=\"disp\">disp</th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"1\" colspan=\"1\" scope=\"col\" id=\"hp\">hp</th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"1\" colspan=\"1\" scope=\"col\" id=\"drat\">drat</th>\n    </tr>\n  </thead>\n  <tbody class=\"gt_table_body\">\n    <tr><th id=\"stub_1_1\" scope=\"row\" class=\"gt_row gt_left gt_stub\">Mazda RX4</th>\n<td headers=\"stub_1_1 mpg\" class=\"gt_row gt_right\">21.0</td>\n<td headers=\"stub_1_1 cyl\" class=\"gt_row gt_right\">6</td>\n<td headers=\"stub_1_1 disp\" class=\"gt_row gt_right\">160</td>\n<td headers=\"stub_1_1 hp\" class=\"gt_row gt_right\">110</td>\n<td headers=\"stub_1_1 drat\" class=\"gt_row gt_right\">3.90</td>\n<td headers=\"stub_1_1 wt\" class=\"gt_row gt_right\">2.620</td>\n<td headers=\"stub_1_1 qsec\" class=\"gt_row gt_right\">16.46</td>\n<td headers=\"stub_1_1 vs\" class=\"gt_row gt_right\">0</td>\n<td headers=\"stub_1_1 am\" class=\"gt_row gt_right\">1</td>\n<td headers=\"stub_1_1 gear\" class=\"gt_row gt_right\">4</td>\n<td headers=\"stub_1_1 carb\" class=\"gt_row gt_right\">4</td></tr>\n    <tr><th id=\"stub_1_2\" scope=\"row\" class=\"gt_row gt_left gt_stub\">Mazda RX4 Wag</th>\n<td headers=\"stub_1_2 mpg\" class=\"gt_row gt_right\">21.0</td>\n<td headers=\"stub_1_2 cyl\" class=\"gt_row gt_right\">6</td>\n<td headers=\"stub_1_2 disp\" class=\"gt_row gt_right\">160</td>\n<td headers=\"stub_1_2 hp\" class=\"gt_row gt_right\">110</td>\n<td headers=\"stub_1_2 drat\" class=\"gt_row gt_right\">3.90</td>\n<td headers=\"stub_1_2 wt\" class=\"gt_row gt_right\">2.875</td>\n<td headers=\"stub_1_2 qsec\" class=\"gt_row gt_right\">17.02</td>\n<td headers=\"stub_1_2 vs\" class=\"gt_row gt_right\">0</td>\n<td headers=\"stub_1_2 am\" class=\"gt_row gt_right\">1</td>\n<td headers=\"stub_1_2 gear\" class=\"gt_row gt_right\">4</td>\n<td headers=\"stub_1_2 carb\" class=\"gt_row gt_right\">4</td></tr>\n    <tr><th id=\"stub_1_3\" scope=\"row\" class=\"gt_row gt_left gt_stub\">Datsun 710</th>\n<td headers=\"stub_1_3 mpg\" class=\"gt_row gt_right\">22.8</td>\n<td headers=\"stub_1_3 cyl\" class=\"gt_row gt_right\">4</td>\n<td headers=\"stub_1_3 disp\" class=\"gt_row gt_right\">108</td>\n<td headers=\"stub_1_3 hp\" class=\"gt_row gt_right\">93</td>\n<td headers=\"stub_1_3 drat\" class=\"gt_row gt_right\">3.85</td>\n<td headers=\"stub_1_3 wt\" class=\"gt_row gt_right\">2.320</td>\n<td headers=\"stub_1_3 qsec\" class=\"gt_row gt_right\">18.61</td>\n<td headers=\"stub_1_3 vs\" class=\"gt_row gt_right\">1</td>\n<td headers=\"stub_1_3 am\" class=\"gt_row gt_right\">1</td>\n<td headers=\"stub_1_3 gear\" class=\"gt_row gt_right\">4</td>\n<td headers=\"stub_1_3 carb\" class=\"gt_row gt_right\">1</td></tr>\n    <tr><th id=\"stub_1_4\" scope=\"row\" class=\"gt_row gt_left gt_stub\">Hornet 4 Drive</th>\n<td headers=\"stub_1_4 mpg\" class=\"gt_row gt_right\">21.4</td>\n<td headers=\"stub_1_4 cyl\" class=\"gt_row gt_right\">6</td>\n<td headers=\"stub_1_4 disp\" class=\"gt_row gt_right\">258</td>\n<td headers=\"stub_1_4 hp\" class=\"gt_row gt_right\">110</td>\n<td headers=\"stub_1_4 drat\" class=\"gt_row gt_right\">3.08</td>\n<td headers=\"stub_1_4 wt\" class=\"gt_row gt_right\">3.215</td>\n<td headers=\"stub_1_4 qsec\" class=\"gt_row gt_right\">19.44</td>\n<td headers=\"stub_1_4 vs\" class=\"gt_row gt_right\">1</td>\n<td headers=\"stub_1_4 am\" class=\"gt_row gt_right\">0</td>\n<td headers=\"stub_1_4 gear\" class=\"gt_row gt_right\">3</td>\n<td headers=\"stub_1_4 carb\" class=\"gt_row gt_right\">1</td></tr>\n    <tr><th id=\"stub_1_5\" scope=\"row\" class=\"gt_row gt_left gt_stub\">Hornet Sportabout</th>\n<td headers=\"stub_1_5 mpg\" class=\"gt_row gt_right\">18.7</td>\n<td headers=\"stub_1_5 cyl\" class=\"gt_row gt_right\">8</td>\n<td headers=\"stub_1_5 disp\" class=\"gt_row gt_right\">360</td>\n<td headers=\"stub_1_5 hp\" class=\"gt_row gt_right\">175</td>\n<td headers=\"stub_1_5 drat\" class=\"gt_row gt_right\">3.15</td>\n<td headers=\"stub_1_5 wt\" class=\"gt_row gt_right\">3.440</td>\n<td headers=\"stub_1_5 qsec\" class=\"gt_row gt_right\">17.02</td>\n<td headers=\"stub_1_5 vs\" class=\"gt_row gt_right\">0</td>\n<td headers=\"stub_1_5 am\" class=\"gt_row gt_right\">0</td>\n<td headers=\"stub_1_5 gear\" class=\"gt_row gt_right\">3</td>\n<td headers=\"stub_1_5 carb\" class=\"gt_row gt_right\">2</td></tr>\n  </tbody>\n  <tfoot class=\"gt_sourcenotes\">\n    <tr>\n      <td class=\"gt_sourcenote\" colspan=\"12\">Dataset is generally available in R</td>\n    </tr>\n  </tfoot>\n  <tfoot class=\"gt_footnotes\">\n    <tr>\n      <td class=\"gt_footnote\" colspan=\"12\"><span class=\"gt_footnote_marks\" style=\"white-space:nowrap;font-style:italic;font-weight:normal;line-height:0;\"><sup>1</sup></span> A table footnote</td>\n    </tr>\n  </tfoot>\n</table>"

---

    Code
      render_as_html(gt_tbl)
    Output
      [1] "<table class=\"gt_table\" data-quarto-disable-processing=\"false\" data-quarto-bootstrap=\"false\">\n  <thead>\n    <tr class=\"gt_heading\">\n      <td colspan=\"12\" class=\"gt_heading gt_title gt_font_normal\" style>The mtcars Dataset<span class=\"gt_footnote_marks\" style=\"white-space:nowrap;font-style:italic;font-weight:normal;line-height:0;\"><sup>1</sup></span></td>\n    </tr>\n    <tr class=\"gt_heading\">\n      <td colspan=\"12\" class=\"gt_heading gt_subtitle gt_font_normal gt_bottom_border\" style>What a great dataset this is</td>\n    </tr>\n    <tr class=\"gt_col_headings gt_spanner_row\">\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_left\" rowspan=\"2\" colspan=\"1\" scope=\"col\" id=\"a::stub\"></th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"2\" colspan=\"1\" scope=\"col\" id=\"mpg\">mpg</th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"2\" colspan=\"1\" scope=\"col\" id=\"cyl\">cyl</th>\n      <th class=\"gt_center gt_columns_top_border gt_column_spanner_outer\" rowspan=\"1\" colspan=\"3\" scope=\"colgroup\" id=\"performance\">\n        <div class=\"gt_column_spanner\">performance</div>\n      </th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"2\" colspan=\"1\" scope=\"col\" id=\"wt\">wt</th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"2\" colspan=\"1\" scope=\"col\" id=\"qsec\">qsec</th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"2\" colspan=\"1\" scope=\"col\" id=\"vs\">vs</th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"2\" colspan=\"1\" scope=\"col\" id=\"am\">am</th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"2\" colspan=\"1\" scope=\"col\" id=\"gear\">gear</th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"2\" colspan=\"1\" scope=\"col\" id=\"carb\">carb</th>\n    </tr>\n    <tr class=\"gt_col_headings\">\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"1\" colspan=\"1\" scope=\"col\" id=\"disp\">disp</th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"1\" colspan=\"1\" scope=\"col\" id=\"hp\">hp</th>\n      <th class=\"gt_col_heading gt_columns_bottom_border gt_right\" rowspan=\"1\" colspan=\"1\" scope=\"col\" id=\"drat\">drat</th>\n    </tr>\n  </thead>\n  <tbody class=\"gt_table_body\">\n    <tr><th id=\"stub_1_1\" scope=\"row\" class=\"gt_row gt_left gt_stub\">Mazda RX4</th>\n<td headers=\"stub_1_1 mpg\" class=\"gt_row gt_right\">21.0</td>\n<td headers=\"stub_1_1 cyl\" class=\"gt_row gt_right\">6</td>\n<td headers=\"stub_1_1 disp\" class=\"gt_row gt_right\">160</td>\n<td headers=\"stub_1_1 hp\" class=\"gt_row gt_right\">110</td>\n<td headers=\"stub_1_1 drat\" class=\"gt_row gt_right\">3.90</td>\n<td headers=\"stub_1_1 wt\" class=\"gt_row gt_right\">2.620</td>\n<td headers=\"stub_1_1 qsec\" class=\"gt_row gt_right\">16.46</td>\n<td headers=\"stub_1_1 vs\" class=\"gt_row gt_right\">0</td>\n<td headers=\"stub_1_1 am\" class=\"gt_row gt_right\">1</td>\n<td headers=\"stub_1_1 gear\" class=\"gt_row gt_right\">4</td>\n<td headers=\"stub_1_1 carb\" class=\"gt_row gt_right\">4</td></tr>\n    <tr><th id=\"stub_1_2\" scope=\"row\" class=\"gt_row gt_left gt_stub\">Mazda RX4 Wag</th>\n<td headers=\"stub_1_2 mpg\" class=\"gt_row gt_right\">21.0</td>\n<td headers=\"stub_1_2 cyl\" class=\"gt_row gt_right\">6</td>\n<td headers=\"stub_1_2 disp\" class=\"gt_row gt_right\">160</td>\n<td headers=\"stub_1_2 hp\" class=\"gt_row gt_right\">110</td>\n<td headers=\"stub_1_2 drat\" class=\"gt_row gt_right\">3.90</td>\n<td headers=\"stub_1_2 wt\" class=\"gt_row gt_right\">2.875</td>\n<td headers=\"stub_1_2 qsec\" class=\"gt_row gt_right\">17.02</td>\n<td headers=\"stub_1_2 vs\" class=\"gt_row gt_right\">0</td>\n<td headers=\"stub_1_2 am\" class=\"gt_row gt_right\">1</td>\n<td headers=\"stub_1_2 gear\" class=\"gt_row gt_right\">4</td>\n<td headers=\"stub_1_2 carb\" class=\"gt_row gt_right\">4</td></tr>\n    <tr><th id=\"stub_1_3\" scope=\"row\" class=\"gt_row gt_left gt_stub\">Datsun 710</th>\n<td headers=\"stub_1_3 mpg\" class=\"gt_row gt_right\">22.8</td>\n<td headers=\"stub_1_3 cyl\" class=\"gt_row gt_right\">4</td>\n<td headers=\"stub_1_3 disp\" class=\"gt_row gt_right\">108</td>\n<td headers=\"stub_1_3 hp\" class=\"gt_row gt_right\">93</td>\n<td headers=\"stub_1_3 drat\" class=\"gt_row gt_right\">3.85</td>\n<td headers=\"stub_1_3 wt\" class=\"gt_row gt_right\">2.320</td>\n<td headers=\"stub_1_3 qsec\" class=\"gt_row gt_right\">18.61</td>\n<td headers=\"stub_1_3 vs\" class=\"gt_row gt_right\">1</td>\n<td headers=\"stub_1_3 am\" class=\"gt_row gt_right\">1</td>\n<td headers=\"stub_1_3 gear\" class=\"gt_row gt_right\">4</td>\n<td headers=\"stub_1_3 carb\" class=\"gt_row gt_right\">1</td></tr>\n    <tr><th id=\"stub_1_4\" scope=\"row\" class=\"gt_row gt_left gt_stub\">Hornet 4 Drive</th>\n<td headers=\"stub_1_4 mpg\" class=\"gt_row gt_right\">21.4</td>\n<td headers=\"stub_1_4 cyl\" class=\"gt_row gt_right\">6</td>\n<td headers=\"stub_1_4 disp\" class=\"gt_row gt_right\">258</td>\n<td headers=\"stub_1_4 hp\" class=\"gt_row gt_right\">110</td>\n<td headers=\"stub_1_4 drat\" class=\"gt_row gt_right\">3.08</td>\n<td headers=\"stub_1_4 wt\" class=\"gt_row gt_right\">3.215</td>\n<td headers=\"stub_1_4 qsec\" class=\"gt_row gt_right\">19.44</td>\n<td headers=\"stub_1_4 vs\" class=\"gt_row gt_right\">1</td>\n<td headers=\"stub_1_4 am\" class=\"gt_row gt_right\">0</td>\n<td headers=\"stub_1_4 gear\" class=\"gt_row gt_right\">3</td>\n<td headers=\"stub_1_4 carb\" class=\"gt_row gt_right\">1</td></tr>\n    <tr><th id=\"stub_1_5\" scope=\"row\" class=\"gt_row gt_left gt_stub\">Hornet Sportabout</th>\n<td headers=\"stub_1_5 mpg\" class=\"gt_row gt_right\">18.7</td>\n<td headers=\"stub_1_5 cyl\" class=\"gt_row gt_right\">8</td>\n<td headers=\"stub_1_5 disp\" class=\"gt_row gt_right\">360</td>\n<td headers=\"stub_1_5 hp\" class=\"gt_row gt_right\">175</td>\n<td headers=\"stub_1_5 drat\" class=\"gt_row gt_right\">3.15</td>\n<td headers=\"stub_1_5 wt\" class=\"gt_row gt_right\">3.440</td>\n<td headers=\"stub_1_5 qsec\" class=\"gt_row gt_right\">17.02</td>\n<td headers=\"stub_1_5 vs\" class=\"gt_row gt_right\">0</td>\n<td headers=\"stub_1_5 am\" class=\"gt_row gt_right\">0</td>\n<td headers=\"stub_1_5 gear\" class=\"gt_row gt_right\">3</td>\n<td headers=\"stub_1_5 carb\" class=\"gt_row gt_right\">2</td></tr>\n  </tbody>\n  <tfoot class=\"gt_sourcenotes\">\n    <tr>\n      <td class=\"gt_sourcenote\" colspan=\"12\">Dataset is generally available in R</td>\n    </tr>\n  </tfoot>\n  <tfoot class=\"gt_footnotes\">\n    <tr>\n      <td class=\"gt_footnote\" colspan=\"12\"><span class=\"gt_footnote_marks\" style=\"white-space:nowrap;font-style:italic;font-weight:normal;line-height:0;\"><sup>1</sup></span> A table footnote</td>\n    </tr>\n  </tfoot>\n</table>"

